@@ -3,7 +3,10 @@
 #
 # Univention Management Console module server-overview
 #
-# Copyright 2017-2022 Univention GmbH
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
+# Copyright 2017-2023 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -31,26 +34,26 @@
 # <https://www.gnu.org/licenses/>.
 
 import univention.admin.modules as udm_modules
-from univention.management.console.config import ucr
 from univention.management.console.base import Base
-from univention.management.console.modules.decorators import simple_response
+from univention.management.console.config import ucr
 from univention.management.console.ldap import get_machine_connection
+from univention.management.console.modules.decorators import simple_response
 
 
 class Instance(Base):
 
-	@simple_response
-	def query(self):
-		udm_modules.update()
-		lo, po = get_machine_connection()
-		servers = udm_modules.lookup('computers/computer', None, lo, filter='(&(|(objectClass=univentionDomainController)(objectClass=univentionMemberServer))(!(univentionObjectFlag=docker)))', base=ucr['ldap/base'], scope='sub')
+    @simple_response
+    def query(self):
+        udm_modules.update()
+        lo, po = get_machine_connection()
+        servers = udm_modules.lookup('computers/computer', None, lo, filter='(&(|(objectClass=univentionDomainController)(objectClass=univentionMemberServer))(!(univentionObjectFlag=docker)))', base=ucr['ldap/base'], scope='sub')
 
-		result = [dict(
-			dn=i.dn,
-			hostname=i.info.get('name'),
-			domain=i.info.get('domain'),
-			ip=i.info.get('ip'),
-			version=i.info.get('operatingSystemVersion'),
-			serverRole=i.info.get('serverRole'),
-		) for i in servers]
-		return result
+        result = [{
+            "dn": i.dn,
+            "hostname": i.info.get('name'),
+            "domain": i.info.get('domain'),
+            "ip": i.info.get('ip'),
+            "version": i.info.get('operatingSystemVersion'),
+            "serverRole": i.info.get('serverRole'),
+        } for i in servers]
+        return result
